<!--

/* 
	DVPortal4.js
	Contains:
		initPage with DVPortal4();

		showTab('a1'); // tabSet and tab number
		switchBlock('navTab',1,'navTab'); // objectID, cookie, and class
		addPngImage();
*/

function DVPortal4() {
	showTab();
	hideEmptyTabs();
	switchBlock();
	fixCSS();
}

/*
showTab.js, v1.2, by Mike Combs
Feb 21, 06 -	Don't set cookies when initializing the page. 
				This ensures we don't set cookies for tabsets a-y unless we use them.
Mar 22, 06 -	Changed from showTabPanel to showTab.
				Added a parameter for cookies.
				Cookies are ON by default.

Current version sets a cookie per tabSet. Future version should use one cookie for all sets

On page init, all tab panels but the first are hidden.
Clicking a link hides all tab panels (divs), reveals one.

First, create tabs as a UL. You must use tabset-X as the ID.
X must be a letter.
<ul class="tabs" id="tabSet-a">
    <li id="tab-a1" class="tabOn"><a href="#tabPanel-a1" onclick="return showTab('a1');">First tab</a></li>
    <li id="tab-a2"><a href="#tabPanel-a2" onclick="return showTab('a2');">Second tab</a></li>
    <li id="tab-a3"><a href="#tabPanel-a3" onclick="return showTab('a3');">Third tab</a></li>
</ul>

Next, create corresponding tab content panels as DIVs. You must use the same tabset- as the ID.
<div class="tabOn" id="tabPanel-a1">
  <h3>First tab stuff</h3>
	 <p>my stuff.</p>
</div>
<div class="tabOn" id="tabPanel-a2">
  <h3>Second tab stuff</h3>
	 <p>my stuff.</p>
</div>
<div class="tabOn" id="tabPanel-a3">
  <h3>Third tab stuff</h3>
	 <p>my stuff.</p>
</div>

Init page with <body onload="showTab();">
- This searches for tabSet-a to tabSet-z. For each found:
- If cookie, restores correct tab and panel.
- If no cookie, hides all but tab panel 1.
If you don't init the page, all tabs will be visible.

Tabs have the tabOn class added or removed them.
In most cases, the CSS file will have something like:
ul.tabs li { font: normal; }
ul.tabs li.tabOn { font: bold; }

TabPanels have class toggled between tabShow and tabHide.
In most cases, the CSS file will have something like:
div.tabOff { display: none; }
div.tabOn { display: block; }
In the HTML, all panels are set to show. This script will hide the non-selected ones. 
If this script fails, you'll still be able to view the tabs.
*/

function showTab(tabID, setCookie) {
	var i, s, tabCookie;
	var alphabet;
	alphabet = 'abcdefghijklmnopqrstuvwxyz';
	var expdate = new Date();

	if (setCookie == undefined) { setCookie = 1; }

	// alert ('tabID='+tabID);
	if (tabID != undefined)
	{
		showTabPanel(tabID);
		// set 1 hour cookie in case page is refreshed, 60000 ticks/minute
		// NOTE: This doesn't work on Opera7 from file://, due to a privacy restriction
		if (setCookie != 0) {
			expdate.setTime(expdate.getTime() + (60*10000));
			c = 'tabSet-' + tSet + '=' + escape(tSet + tNumber) + '; expires=' + expdate.toGMTString() + '; path=/';
			document.cookie = c;
		}
	} else {
		for(i=1; i<=26; i++) {
			s=alphabet.charAt(i-1);
			tabCookie= 'tabSet-' + s;
			tabID = readCookie(tabCookie);
			if (tabID == "") { tabID = s + '1'; }
			showTabPanel(tabID);
		}
	}
	return false;
}

function showTabPanel(tabID) {
//alert ('tabID='+tabID);
	var tabName, panelName;
	var expdate = new Date();
	var c;
	tSet = tabID.charAt(0);
	tNumber = tabID.charAt(1);
	for(t = 1; t <= 9; t++) {
		tabName = 'tab-' + tSet + t.toString();
		if (document.getElementById(tabName)) {
				document.getElementById(tabName).className = (tNumber == t) ? 'tabOn':'tabOff';
				panelName = 'tabPanel-' + tSet + t.toString();
//if (t==1) { alert('tabPanel='+panelName); }
//if (t==tNumber) { alert('match tabPanel='+panelName); }
				document.getElementById(panelName).className = (tNumber == t) ? 'tabOn':'tabOff';
		}
	}
	return false;
}

/*
switchBlock, v1.1, by Mike Combs
Feb 25, 04 - First version
Mar 13, 06 - Added cookie support, aligned with showTabPanel syntax

On page init, cookie is read for a list of objects (usually DIVs) to switch on or off.
Clicking link toggles classname between "sbOn" and "sbOff".
Used to work by adding "hide" as a class, but IE6 doesn't support multiple class selectors

Init page with <body onload="switchBlock();">
Params: ID to switch, cookie (1=yes, 0=no/remove), className
Sample HTML for button:
	<p><a href="#" onclick="return switchBlock('bar1');">Toggle bar1</a></p>
	<p><a href="#" onclick="return switchBlock('bar2',1,'chart');">Toggle bar2, with cookie</a></p>
	<p><a href="#" onclick="switchBlock('bar1'); return switchBlock('pie1');">Toggle bar1 and pie1</a></p>
Sample HTML for object:
	<div id="bar1" class="sbOn">This div is bar1.</div>
	<div id="bar2" class="chartOn">This div is bar2.</div>
	<div id="pie1" class="sbOn">This div is pie1.</div>
Sample CSS for object:
	div.sbOn { display: block; }
	div.chartOn { display: block; background: blue; }
	div.sbOff, div.chartOff { display: none; }

*/

function switchBlock(objectID, setCookie, rootClass) {
	var expdate = new Date();
	if (objectID != undefined)
	{
		if (rootClass == undefined) { rootClass = 'sb';	}
		setObjectClass(objectID, rootClass);

		// format of cookie is:
		// bar1>sbOn,bar2>chartOn,pie1>sbOff
		if ((setCookie == 0) || (setCookie == undefined))
		{
			// clear cookie if it exists (not implemented, they'll have to use browser)
		} else {
			// set cookie, replace if it exists
			// what class did we set it to?
			oldClasses = document.getElementById(objectID).className;
			oldClass = undefined;
			if (indexOfWord(oldClasses,rootClass + 'On') > -1) { oldClass = rootClass + 'On'; }
			if (indexOfWord(oldClasses,rootClass + 'Off') > -1) { oldClass = rootClass + 'Off';	}
			// now replace or add the state
// alert('oldCookie='+readCookie('switchBlock'));
			block = readCookie('switchBlock').split(",");
			sbCookie = '';
			weReplacedOldCookie = 0;
			for(iBlock=0; iBlock<block.length; iBlock++) {
				blockState = block[iBlock];
				if (blockState != '') {
//alert('blockState '+iBlock+' of '+block.length+'='+blockState);
					blockID = blockState.substring(0,blockState.indexOf('>'));
					blockClass = block[iBlock].substring(blockID.length+1,blockState.length);
					sbCookie = (sbCookie.length > 0) ? sbCookie + ',' : sbCookie;
					if (blockID == objectID) {
						weReplacedOldCookie = 1;
						sbCookie = sbCookie + blockID + '>' + oldClass;
					} else {
						sbCookie = sbCookie + blockID + '>' + blockClass;
					}
				}
			}
			// if we didn't find a match, add the cookie
			if (weReplacedOldCookie == 0) {
				sbCookie = (sbCookie.length > 0) ? sbCookie + ',' : sbCookie;
				sbCookie = sbCookie + objectID + ">" + oldClass;
			}
//alert('cookie='+sbCookie);
//sbCookie='';
			// set 1 hour cookie in case page is refreshed, 60000 ticks/minute
			// NOTE: This doesn't work on Opera7 from file://, due to a privacy restriction
			expdate.setTime(expdate.getTime() + (60*10000));
			c = 'switchBlock=' + sbCookie + '; expires=' + expdate.toGMTString() + '; path=/';
			document.cookie = c;
		}
	} else {
		// if no params, read and set all objects from cookie
//alert('oldCookie='+readCookie('switchBlock'));
		c=readCookie('switchBlock');
		block = readCookie('switchBlock').split(",");
		for(iBlock=0; iBlock<block.length; iBlock++) {
			blockState = block[iBlock];
			if (blockState != '') {
//alert('blockState='+blockState);
				blockID = blockState.substring(0,blockState.indexOf('>'));
				blockClass = block[iBlock].substring(blockID.length+1,blockState.length);
				setObjectClass(blockID, blockClass);
			}
		}
	}
}

function setObjectClass(objectID, theClass) {
	// send "sbOn" to set the class and state
	// send "sb" to change state

	rootClass = 'sb';
	if (theClass.substring(theClass.length-3,theClass.length) == 'Off') {
		rootClass = theClass.substring(0,theClass.length-3);
		newClass = theClass;
	} else {
		if (theClass.substring(theClass.length-2,theClass.length) == 'On') {
			rootClass = theClass.substring(0,theClass.length-2);
			newClass = theClass;
		} else {
			rootClass = theClass;
			newClass = '';
		}
	}
//alert('newClass='+rootClass);

	oldClasses = document.getElementById(objectID).className;
	oldClass = undefined;
	if (indexOfWord(oldClasses,rootClass + 'On') > -1) { oldClass = rootClass + 'On'; }
	if (indexOfWord(oldClasses,rootClass + 'Off') > -1) { oldClass = rootClass + 'Off';	}

	// set newClass to be sbOn or sbOff. If no oldClass, newClass is sbOff.
    if (newClass == '') {
		newClass = (oldClass == rootClass + 'Off') ? rootClass + 'On' : rootClass + 'Off';
	}

	// remove old class (sbOn/sbOff) from list of classes, add new class
	if (oldClasses == undefined)
	{ 
		newClasses = newClass;
	} else {
		foundLoc = indexOfWord(oldClasses,oldClass);
		newClassesL = oldClasses.substring(0,foundLoc); // empty or ends with a space
		newClassesR = oldClasses.substring(foundLoc+oldClass.length,oldClasses.length); // empty or starts with space
		newClasses = newClassesL + newClass + newClassesR;
		// alert('old classes=' + oldClasses + ' newstate=' + newState + ' new classes=' + newClasses);
	}
	document.getElementById(objectID).className = newClasses;
    // self.location = self.location;
	return true;
}

function indexOfWord(theString, theWord) {
	// find word but not if it's embedded in another word
	// return index
	if (theString == theWord) {	return 0; }
	if (theString.indexOf(' ' + theWord + ' ') > -1) { return theString.indexOf(' ' + theWord + ' ') +1; }
	if (theString.indexOf(theWord + ' ') == 0) { return 0; }
	if (theString.indexOf(' ' + theWord) == theString.length-theWord.length+1) { return theString.indexOf(' ' + theWord) +1; }
	return -1;
}

function readCookie(name) {
	var i = 0; 
	var lookfor = name + "=";
	while (i < document.cookie.length) {
		var j = i + lookfor.length
		// alert(document.cookie + ' found ' + document.cookie.substring(i,j));
		if (document.cookie.substring(i,j) == lookfor) {
			var endstr = document.cookie.indexOf(";", j)
			if (endstr == -1) {
				endstr = document.cookie.length
			}
			return unescape(document.cookie.substring(j, endstr))
		}
		i = document.cookie.indexOf(" ", i) + 1;
		if (i == 0) {
			break
		}
	}
	return ""
}



/*
ie_pngtransparency

version 1.0, put here by Mike Combs

Source:
	http://www.codeproject.com/jscript/IEPNGsupport.asp?df=100&forumid=106369&select=1013665#xx930433xx
	http://webfx.eae.net/dhtml/pngbehavior/pngbehavior.html
	http://www.webmasterworld.com/forum83/7828.htm

To apply this to all foreground images, add this to your CSS in one place:
	img {
			filter:expression(addPngImage(this));
	}

To apply this to background images, use this for each background image:
	background: url('../Images/mel_h3_back.png') top left no-repeat;
	* background-image: none;
	filter:progid:DXImageTransform.Microsoft.alphaimageloader(src='../Objectstore/Images/mel_h3_back.png', sizingMethod='scale'); 
*/


//Array containing all PNG images on the page
var PNGimageArray = new Array();
var isPrinting = false;

//Path to the blank image (1x1 transparent)
var blankSrc = "../Objectstore/Images/spacer.gif";

//Setup events
if (window.attachEvent)
{
	// IE print events
	window.attachEvent("onbeforeprint", function () { beforePrint(); } );
	window.attachEvent("onafterprint", function () { afterPrint(); } );                               
	
	// onload
	window.attachEvent("onload", DVPortal4 );
}
else
{
	// onload
	window.addEventListener("load", DVPortal4, false);
}
													  
//Tests if element is a PNG image, and if so fixes it
function addPngImage(element){
	if (/\.png$/i.test(element.src)) {
		fixImage(element);
		element.attachEvent("onpropertychange", function () { propertyChanged(); } );
		PNGimageArray[PNGimageArray.length] = element;
	}
}

//Applies filter and changes source to blank
function fixImage(element) {
	element.runtimeStyle.filter =  "progid:DXImageTransform.Microsoft.AlphaImageLoader()";
	element.filters.item("DXImageTransform.Microsoft.AlphaImageLoader").src=element.src;

	width = element.width;
	height = element.height;
	element.src = blankSrc;
	element.setAttribute("width",width);
	element.setAttribute("height",height);

}

//If property "src" is changed fix image (not if it is changed to blank though)
function propertyChanged() {
	if (isPrinting) return;
	var element = event.srcElement;
	var pName = event.propertyName;
	if (pName != "src") return;
	if (!new RegExp(blankSrc).test(element.src))
		fixImage(element);

}

//Turns image back to original before print (Explorer can't print filters)
function beforePrint() {
	isPrinting = true;
	var element;
	for(var i = 0; i < PNGimageArray.length; i++){
		element = PNGimageArray[i];
		element.src = element.filters[0].src;
		element.runtimeStyle.filter = "";
	}

}

//Fixes image after print
function afterPrint() {
	isPrinting = false;
	var element;
	for(var i = 0; i < PNGimageArray.length; i++){
		element = PNGimageArray[i];
		fixImage(element);

	}
}
/* This function fixes up some of the problems discovered during the
/  initial roll-out of DVPortal4. AppPacks often does not populate
/  all of the controls on a page, or will leave table and chart title
/  controls empty. In DVPortal4 this would result in empty bordered 
/  boxes or colored bars with no text. So, this function walks the 
/  DOM, finds these empty objects, and sets their display style to 
/  "none." It should be called from the onload handler of the 
/  DVPortal4.html page.
*/

function fixCSS() {
	var reportFrame = document.getElementById("reportLayout");
	if (reportFrame) {
		var h3Tags = reportFrame.getElementsByTagName("H3");
		var divTags = reportFrame.getElementsByTagName("DIV");
		for (i = 0; i < h3Tags.length; i++) {
			tag = h3Tags[i];
			if (tag.innerHTML.length < 1) {
				tag.style.display = "none";
			}
		}
		for (i = 0; i < divTags.length; i++ ) {
			var tag = divTags[i];
			var images = tag.getElementsByTagName("IMG");
			var tables = tag.getElementsByTagName("TABLE");
			var spans = tag.getElementsByTagName("SPAN");
			var lists = tag.getElementsByTagName("LI");
			if ((images.length + tables.length + spans.length + lists.length) < 1) {
				tag.style.display = "none";
			}
		}
	}
	var horzLinksDiv = document.getElementById("HorzLinks");
	var propertyListDiv = document.getElementById("PropertyList");
	if (horzLinksDiv) {
		var anchors = horzLinksDiv.getElementsByTagName("A");
		if (anchors.length == 0) {
			horzLinksDiv.style.border = "0 none";
		}
	}
	if (propertyListDiv) {
		var spans = propertyListDiv.getElementsByTagName("SPAN");
		if (spans.length == 0) {
			propertyListDiv.style.border = "0 none";
		}
	}
}

function hideEmptyTabs() {
//	alert("Starting hideEmptyTabPanels");
	var lists = document.getElementsByTagName("UL");
	for (i = 0; i<lists.length; i++) {
		if (lists[i].id.indexOf("tabSet-") > -1) {
//			alert(lists[i].id);
			var listElements = lists[i].getElementsByTagName("LI");
			for (j = 0; j<listElements.length; j++) {
				var anchors = listElements[j].getElementsByTagName("A");
				if (anchors[0].innerHTML.length < 1) {
//					alert("empty anchor, hiding tab");
					listElements[j].style.display = "none";
				}		
			}
		}
	}
}

//-->

tooltipTextCache = new Array();

function showTooltip(tooltip, resourceId, metricId, startTime, endTime, timeSpan, timeZone)
{
	tooltipString = getTooltipText(resourceId, metricId, startTime, endTime, timeSpan, timeZone);
	if (tooltipString != null && tooltipString != "")
	{
		document.getElementById(tooltip).innerHTML = tooltipString;
		document.getElementById(tooltip).className = "tooltip-show";
	}
}

function hideTooltip(tooltip)
{
	document.getElementById(tooltip).className = "tooltip-hide";
}

function getTooltipText(resourceId, metricId, startTime, endTime, timeSpan, timeZone)
{
	lookupString = resourceId + ":" + metricId;
	if (tooltipTextCache[lookupString])
		return tooltipTextCache[lookupString];

	if (window.XMLHttpRequest)
		request = new XMLHttpRequest();
	else if (window.ActiveXObject)
		request = new ActiveXObject("Microsoft.XMLHTTP");

	request.open("GET", "../../PROVISO/DataView/tooltipText?resourceId=" + resourceId + "&metricId=" + metricId + 
		"&startTime=" + startTime + "&endTime=" + endTime + "&timeSpan=" + timeSpan + "&timeZone=" + timeZone, false);
	request.send("");

	tooltipTextCache[lookupString] = request.responseText;
	return request.responseText;
}
